@@ -17,30 +17,21 @@ use URI::Escape;
 sub find_video {
   my ($self, $browser) = @_;
 
-
   # Get the video ID
-  #  on cherche:	"idMedia":"T7AYXvq2l5DZy578Zj_c0LGWurfWkQs_"
+  #  on cherche:	,"pid":"45Kr9K8SfwVF1Q5anv7TrRpWa6nMtkG4",
   my $video_id;
-  if ($browser->content =~ /"idMedia":"(\w+)"/i) {
+  if ($browser->content =~ /,"pid":"(\w+)"/) {
     $video_id = $1;
   }
   debug "Video ID = " . $video_id;
 
   die "Couldn't find TOU.TV video ID" unless $video_id;
 
+  # on cherche:		,"titleId":"2010-03-29_CA_0052"
   my $filename;
-  # on cherche:		<meta content="les-chefs" name="src.emission" />
-  if ($browser->content =~ /<meta\s+content="(\S+)"\s+name="\w+.emission"/i) {
+  if ($browser->content =~ /,"titleId":"([^"]+)"/) {
     $filename =  $1 ;
   }
-  # on cherche:		<meta content="1513429386.S03E02" name="ProfilingEmisodeToken"
-  if ($browser->content =~ /<meta\s+content="(\S+)"\s+name="ProfilingEmisodeToken"/i) {
-    my $episode = $1;
-    if($episode =~ /\S+\.(\S+)/) {
-        $episode = $1;
-    }
-    $filename =  $filename . "." . $episode ;
-  }
   debug "Filename = " . $filename;
 
   # On va chercher le XML qui contient le lien RTMP
@@ -52,28 +43,28 @@ sub find_video {
 
   # on cherche:  	rtmp://medias-flash.tou.tv/ondemand/?auth=daEdwc5 etc...52_hr.mov
   my $url;
-  if ($browser->content =~ /(rtmp:[^\<]+)/i) {
+  if ($browser->content =~ /(rtmp:[^\<]+)/) {
     $url = uri_unescape($1);
   }
   debug "URL = " . $url;
 
   # on cherche:		auth=daEdrbRdbbtcYbUb3bQbzacdOaIbNczbva9-blS.uA-cOW-9rqBvkLqxBB
   my $auth;
-  if ($url =~ /auth=([^&]+)/i) {
+  if ($url =~ /auth=([^&]+)/ ) {
     $auth = uri_unescape($1);
   }
   debug "AUTH = " . $auth;
 
   #	on decoupe a partir de 'ondemand/'
   my $app;
-  if ($url =~ /(ondemand\/.+)/i) {
+  if ($url =~ /(ondemand\/.+)/ ) {
     $app = uri_unescape($1);
   }
   debug "APP = " . $app;
 
   #  on decoupe apres <break>
   my $playpath;
-  if ($url =~ /&lt;break&gt;(.+)/i) {
+  if ($url =~ /&lt;break&gt;(.+)/ ) {
     $playpath = uri_unescape($1);
   }
   debug "PLAYPATH = " . $playpath;
