@@ -8,9 +8,6 @@ use FlashVideo::Utils;
 use FlashVideo::JSON;
 use URI::Escape;
 
-our $VERSION = '0.02';
-sub Version { $VERSION; }
-
 my @formats = (
   { id => 38, resolution => [4096, 2304] },
   { id => 37, resolution => [1920, 1080] },
@@ -26,16 +23,9 @@ my @formats = (
 sub find_video {
   my ($self, $browser, $embed_url, $prefs) = @_;
 
-  # There are a few different kinds of URLs that end up on the same page
-  # So, let's canonicalize to the "real" one
-  if ($browser->content =~ m!<link *rel=['"]canonical['"] *href=['"]([^'"]*)!) {
-    $embed_url = "http://www.youtube.com$1"
-  }
-
   if($embed_url !~ m!youtube\.com/watch!) {
     $browser->get($embed_url);
     if ($browser->response->header('Location') =~ m!/swf/.*video_id=([^&]+)!
-        || $browser->content =~ m!\<iframe[^\>]*src="http://www.youtube.com/embed/([^"]+)"!i
         || $embed_url =~ m!/v/([-_a-z0-9]+)!i
         || $browser->uri =~ m!v%3D([-_a-z0-9]+)!i) {
       # We ended up on a embedded SWF or other redirect page
@@ -58,21 +48,13 @@ sub find_video {
   # If the page contains fmt_url_map, then process this. With this, we
   # don't require the 't' parameter.
   if ($browser->content =~ /["']fmt_url_map["']:\s{0,3}(["'][^"']+["'])/) {
-    my $fmt_map = $1;
-    if ($fmt_map !~ /\|/) {
-      # $fmt_map is double escaped. We should unescape it here just
-      # once.  Be careful not to unescape ',' in the URL.
-      $fmt_map = uri_unescape($fmt_map);
-    }
-    debug "Using fmt_url_map method from page ($fmt_map)";
-    return $self->download_fmt_map($prefs, $browser, $title, {}, @{from_json $fmt_map});
+    debug "Using fmt_url_map method from page ($1)";
+    return $self->download_fmt_map($prefs, $browser, $title, {}, @{from_json $1});
   }
 
   my $video_id;
   if ($browser->content =~ /(?:var pageVideoId =|(?:CFG_)?VIDEO_ID'?\s*:)\s*'(.+?)'/
-      || $browser->content =~ /[&?]video_id=([^&"]+)/
-      || $embed_url =~ /v=([^&#]+)/
-      || $browser->content =~ /&amp;video_id=([^&]+)&amp;/) {
+      || $embed_url =~ /v=([^&]+)/) {
     $video_id = $1;
   } else {
     check_die($browser, "Couldn't extract video ID");
@@ -143,12 +125,6 @@ sub find_video {
     } elsif($info{fmt_url_map}) {
       debug "Using fmt_url_map method from info";
       return $self->download_fmt_map($prefs, $browser, $title, \%info, $info{fmt_url_map});
-    } elsif($info{url_encoded_fmt_stream_map}) {
-      debug "Using url_encoded_fmt_stream_map method from info";
-      if ($info{title}) {
-        $title=$info{title};
-      }
-      return $self->download_url_encoded_fmt_stream_map($prefs, $browser, $title, \%info, $info{url_encoded_fmt_stream_map});
     }
   }
 
@@ -156,56 +132,6 @@ sub find_video {
   return download_get_video($browser, $prefs, $video_id, $title, $t);
 }
 
-sub download_url_encoded_fmt_stream_map {
-  my($self, $prefs, $browser, $title, $info, $fmt_map) = @_;
-
-  my $fmt_url_map = parse_youtube_url_encoded_fmt_stream_map($fmt_map);
-
-  if (!$title and $browser->uri->as_string =~ m'/user/.*?#') {
-    my $video_id = (split /\//, $browser->uri->fragment)[-1];
-
-    my %info = get_youtube_video_info($browser->clone, $video_id);
-
-    $title = $info->{title};
-  }
-
-  my $preferred_quality = $prefs->quality->choose(map { $fmt_url_map->{$_->{id}}
-      ? { resolution => $_->{resolution}, url => $fmt_url_map->{$_->{id}} }
-      : () } @formats);
-
-  $browser->allow_redirects;
-
-  return $preferred_quality->{url}, title_to_filename($title, "mp4");
-}
-
-sub parse_youtube_url_encoded_fmt_stream_map {
-  my($raw_map) = @_;;
-
-  my $map = {};
-
-  foreach my $params (split /,/, $raw_map) {
-    
-    my $format = "";
-    my $url = "";
-    my $signature = "";
-    
-    foreach my $pair (split /&/, $params) {
-      my ($name, $value) = split /=/, $pair;
-      if ($name eq "itag"){
-        $format = $value;
-      } elsif ($name eq "url") {
-        $url = uri_unescape($value);
-      } elsif ($name eq "sig") {
-        $signature = $value;
-      }
-    }
-    
-    $map->{$format} = $url."&signature=".$signature;
-  }
-  
-  return $map;
-}
-
 sub download_fmt_map {
   my($self, $prefs, $browser, $title, $info, $fmt_map) = @_;
 
@@ -379,7 +305,7 @@ EOT
   }
   else {
     # Lame Youtube redirection to uk.youtube.com and so on.
-    if ($browser->response->code == 301 || $browser->response->code == 302) {
+    if ($browser->response->code == 302) {
       $browser->get($browser->response->header('Location'));
     }
 
@@ -407,7 +333,7 @@ sub get_youtube_video_info {
       "http://www.youtube.com/get_video_info?&video_id=%s&el=$el&ps=default&eurl=%s&hl=en_US&t=%s";
 
     my $video_info_url = sprintf $video_info_url_template,
-      uri_escape($video_id), uri_escape($url), uri_escape_utf8($t);
+      uri_escape($video_id), uri_escape($url), uri_escape($t);
 
     debug "get_youtube_video_info: $video_info_url";
 
